# ttf2dxf

simple python based ttf to dxf converter

## quikstart

### install with pip
```
pip3 install ttf2dxf
```

### get code
```
git clone git@github.com:multigcs/ttf2dxf.git
cd ttf2dxf
pip3 install -r requirements.txt
```

### ttf2dxf example
```
ttf2dxf -f ./Arial.ttf -t "ttf2dxf" -o text.dxf
```

![gcodepreview](https://raw.githubusercontent.com/multigcs/ttf2dxf/main/docs/ttf2dxf.png)
